@@ -6,7 +6,7 @@ use Poz::Builder;
 use Exporter 'import';
 use Carp;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 our @EXPORT_OK = qw/z/;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -19,6 +19,8 @@ $Carp::Internal{'Poz::Types::string'}++;
 $Carp::Internal{'Poz::Types::number'}++;
 $Carp::Internal{'Poz::Types::object'}++;
 $Carp::Internal{'Poz::Types::array'}++;
+$Carp::Internal{'Poz::Types::enum'}++;
+$Carp::Internal{'Poz::Types::union'}++;
 
 sub z {
     return Poz::Builder->new;
